@@ -125,7 +125,7 @@
 logis_fe <- function(formula = NULL, data = NULL,
                      Y.char = NULL, Z.char = NULL, ProvID.char = NULL,
                      Y = NULL, Z = NULL, ProvID = NULL,
-                     method = "SerBIN", max.iter = 1000, tol = 1e-5, bound = 10,
+                     method = "SerBIN", max.iter = 10000, tol = 1e-5, bound = 10,
                      cutoff = 10, backtrack = TRUE, stop = "or", threads = 1, message = TRUE) {
   if (!is.null(formula) && !is.null(data)) {
     if (message == TRUE) message("Input format: formula and data.")
@@ -217,12 +217,15 @@ logis_fe <- function(formula = NULL, data = NULL,
   gamma.prov <- rep(log(mean(data[,Y.char])/(1-mean(data[,Y.char]))), length(n.prov))
   beta <- rep(0, NCOL(Z))
 
+  start_time_cpp <- Sys.time()
+
   if (method == "SerBIN") {
     ls <- logis_BIN_fe_prov(as.matrix(data[,Y.char]), Z, n.prov, gamma.prov, beta,
                             threads = threads, tol, max.iter, bound, message, backtrack, stop)
     gamma.prov <- as.numeric(ls$gamma)
     beta <- as.numeric(ls$beta)
-  }
+    }
+
   else if (method == "BAN") {
     ls <- logis_fe_prov(as.matrix(data[,Y.char]), Z, n.prov, gamma.prov, beta,
                         backtrack, max.iter, bound, tol, message, stop)
@@ -233,6 +236,9 @@ logis_fe <- function(formula = NULL, data = NULL,
     stop("Argument 'method' NOT as required!")
   }
 
+  end_time_cpp <- Sys.time()
+  cpp_time <- end_time_cpp - start_time_cpp
+
   # Coefficient
   beta <- matrix(beta)
   gamma.prov <- matrix(gamma.prov)
@@ -300,6 +306,8 @@ logis_fe <- function(formula = NULL, data = NULL,
   # return_ls$df.prov <- df.prov
   return_ls$char_list <- char_list
   return_ls$data_include <- data
+
+  #return_ls$cpp_time <- cpp_time
   return(return_ls)
 }
 
